Models
========================================================

.. toctree::
    :maxdepth: 1

    Base Class for SynthesizerModel <base>


Built-in ML Models
-----------------------------

.. toctree::
    :maxdepth: 2

    ML Models <ml/index>


Build-in Statistical Models
-----------------------------

.. toctree::
    :maxdepth: 2

    Statistics Models <statistics/index>


Custom Models Relevant
-----------------------------

.. toctree::
    :maxdepth: 2

    Extension hookspec <extension>
    ModelManager <manager>
